import pytest
from src.pyRandomMedia.pyMediaFunctions import get_song
from src.pyRandomMedia.pyMediaFunctions import get_news
from src.pyRandomMedia.pyMediaFunctions import get_random_TV_show

class Tests:
    def test_sanity_check(self):
        expected = True  # the value we expect to be present
        actual = True  # the value we see in reality
        assert actual == expected, "Expected True to be equal to True!"
    
    #Tests for Song Function:
    def test_song_inputs(self):
        actual = get_song("Pop")[1]["genre"]
        assert "Pop" in actual, f"Expected the genre to contain the word Pop, but {actual} does not contain Pop."
        actual = get_song("Hip Hop", artist="Eminem")
        assert "Hip Hop" in actual[1]["genre"] and "Eminem" in actual[1]["artist"], f"Expected the genre string to contain Hip Hop and the artist string to contain Eminem, but {actual} does not fulfill these conditions."
        actual = get_song("Pop", song_name="Stressed")
        assert "Stressed" in actual[0] and "Pop" in actual[1]["genre"], f"Expected the name of the song to contain Stressed and the genre to contain Pop, but {actual} does not fulfill these conditions"

    def test_type_error(self):
        with pytest.raises(TypeError):
            get_song("Pop", release_date=2011)
    
    def test_song_not_found(self):
        actual = get_song("Grime")
        assert actual == "No songs found in our list", f"Expected to not find a song because there are no Grime songs in songs_file, but {actual} was found."
    
    #Tests for News Function:

    def test_newsValues(self):
        curr = get_news();
        for item in curr:
            assert isinstance(item, dict), "Each item in the array must be a dictionary"
            assert 'title' in item, "Each dictionary must have a 'title' key"
            assert 'link' in item, "Each dictionary must have a 'link' key"
            assert 'pubDate' in item, "Each dictionary must have a 'pubDate' key"
            assert 'url' in item["source"], "Each source must have a 'url' key"
            assert 'name' in item["source"], "Each source must have a 'name' key"

    def test_inTitle(self):
        inTitleString = "a"
        curr = get_news({ "inTitle": inTitleString })
        for item in curr:
            assert isinstance(item, dict), "Each item in the array must be a dictionary"
            assert 'title' in item, "Each dictionary in the array must have a 'title' key"
            assert isinstance(item['title'], str), "The 'title' key in each dictionary must be a string"
            assert inTitleString in item['title'], f"The substring '{inTitleString}' is not present in the title: {item['title']}"

    def test_maxNum(self):
        curr = get_news({ "num": 10 })
        assert len(curr) <= 10, "The number of articles should be less than or equal to num value"
    
    #Tests for TV show function

    def test_return_type(self):
        """Test if the return type of get_random_TV_show is a dictionary."""
        result = get_random_TV_show()
        assert isinstance(result, dict), "Expected result to be a dictionary."

    def test_dictionary_keys(self):
        """Test if the dictionary has the correct keys."""
        expected_keys = ['title', 'director', 'cast', 'release_year']
        result = get_random_TV_show()
        for key in expected_keys:
            assert key in result, f"Missing '{key}' in the result dictionary."

    def test_non_empty_values(self):
        """Test that the values for each key in the dictionary are not empty."""
        result = get_random_TV_show()
        for key, value in result.items():
            assert value, f"Expected '{key}' to have a non-empty value."


           




songs = {
    "Too Good At Goodbyes": {
        "artist": "Sam Smith",
        "album": "The Thrill of It All",
        "genre": "Pop",
        "release_date": "2017-09-08"
    },
    "Bad Romance": {
        "artist": "Lady Gaga",
        "album": "The Fame Monster",
        "genre": "Pop",
        "release_date": "2009-10-26"
    },
    "The Less I Know The Better": {
        "artist": "Tame Impala",
        "album": "Currents",
        "genre": "Psychedelic Pop",
        "release_date": "2015-11-17"
    },
    "Let Me Down Slowly": {
        "artist": "Alec Benjamin",
        "album": "Narrated for You",
        "genre": "Pop",
        "release_date": "2018-12-07"
    },
    "Pumped Up Kicks": {
        "artist": "Foster The People",
        "album": "Torches",
        "genre": "Indie Pop",
        "release_date": "2010-09-14"
    },
    "Love The Way You Lie": {
        "artist": "Eminem , Rihanna",
        "album": "Recovery",
        "genre": "Hip Hop",
        "release_date": "2010-06-18"
    },
    "7 rings": {
        "artist": "Ariana Grande",
        "album": "thank u, next",
        "genre": "Pop",
        "release_date": "2019-01-18"
    },
    "Skyfall": {
        "artist": "Adele",
        "album": "Skyfall - Single",
        "genre": "Soul",
        "release_date": "2012-10-05"
    },
    "Photograph": {
        "artist": "Ed Sheeran",
        "album": "x",
        "genre": "Pop",
        "release_date": "2014-06-20"
    },
    "Give Me Everything (feat. Nayer)": {
        "artist": "Pitbull , AFROJACK",
        "album": "Planet Pit",
        "genre": "Hip Hop",
        "release_date": "2011-03-22"
    },
    "Love Yourself": {
        "artist": "Justin Bieber",
        "album": "Purpose",
        "genre": "Pop",
        "release_date": "2015-11-09"
    },
    "Only Girl (In The World)": {
        "artist": "Rihanna",
        "album": "LOUD",
        "genre": "Pop",
        "release_date": "2010-09-10"
    },
    "Stay With Me": {
        "artist": "Sam Smith",
        "album": "In the Lonely Hour",
        "genre": "Pop",
        "release_date": "2014-04-14"
    },
    "Uptown Funk (feat. Bruno Mars)": {
        "artist": "Mark Ronson , Bruno Mars",
        "album": "Uptown Special",
        "genre": "Funk",
        "release_date": "2014-11-10"
    },
    "LA CANCIÓN": {
        "artist": "J Balvin , Bad Bunny",
        "album": "Oasis",
        "genre": "Reggaeton",
        "release_date": "2019-06-28"
    },
    "Daddy Issues": {
        "artist": "The Neighbourhood",
        "album": "I Love You.",
        "genre": "Indie Pop",
        "release_date": "2013-04-19"
    },
    "Closer": {
        "artist": "The Chainsmokers , Halsey",
        "album": "Collage",
        "genre": "Electronic",
        "release_date": "2016-07-29"
    },
    "Memories": {
        "artist": "Maroon 5",
        "album": "Memories - Single",
        "genre": "Pop",
        "release_date": "2019-09-20"
    },
    "Love On The Brain": {
        "artist": "Rihanna",
        "album": "ANTI",
        "genre": "R&B",
        "release_date": "2016-09-27"
    },
    "A Sky Full of Stars": {
        "artist": "Coldplay",
        "album": "Ghost Stories",
        "genre": "Pop",
        "release_date": "2014-05-02"
    },
    "LOVE. FEAT. ZACARI.": {
        "artist": "Kendrick Lamar , Zacari",
        "album": "DAMN.",
        "genre": "Hip Hop",
        "release_date": "2017-04-14"
    },
    "All of Me": {
        "artist": "John Legend",
        "album": "Love in the Future",
        "genre": "R&B",
        "release_date": "2013-08-12"
    },
    "I'm Not The Only One": {
        "artist": "Sam Smith",
        "album": "In the Lonely Hour",
        "genre": "Pop",
        "release_date": "2014-08-31"
    },
    "when the party's over": {
        "artist": "Billie Eilish",
        "album": "WHEN WE ALL FALL ASLEEP, WHERE DO WE GO?",
        "genre": "Pop",
        "release_date": "2018-10-17"
    },
    "Summer": {
        "artist": "Calvin Harris",
        "album": "Motion",
        "genre": "Electronic",
        "release_date": "2014-03-14"
    },
    "Timber": {
        "artist": "Pitbull , Kesha",
        "album": "Meltdown",
        "genre": "Dance",
        "release_date": "2013-10-07"
    },
    "Story of My Life": {
        "artist": "One Direction",
        "album": "Midnight Memories",
        "genre": "Pop",
        "release_date": "2013-10-28"
    },
    "Let Me Love You": {
        "artist": "DJ Snake , Justin Bieber",
        "album": "Encore",
        "genre": "Electronic",
        "release_date": "2016-08-05"
    },
    "Young And Beautiful": {
        "artist": "Lana Del Rey",
        "album": "The Great Gatsby: Music from Baz Luhrmann's Film",
        "genre": "Indie Pop",
        "release_date": "2013-04-23"
    },
    "Stressed Out": {
        "artist": "Twenty One Pilots",
        "album": "Blurryface",
        "genre": "Indie Pop",
        "release_date": "2015-04-28"
    },
    "Ni**as In Paris": {
        "artist": "JAY-Z , Kanye West",
        "album": "Watch the Throne",
        "genre": "Hip Hop",
        "release_date": "2011-09-13"
    },
    "SICKO MODE": {
        "artist": "Travis Scott",
        "album": "ASTROWORLD",
        "genre": "Hip Hop",
        "release_date": "2018-08-21"
    },
    "One Kiss (with Dua Lipa)": {
        "artist": "Calvin Harris , Dua Lipa",
        "album": "One Kiss - Single",
        "genre": "House",
        "release_date": "2018-04-06"
    },
    "What Makes You Beautiful": {
        "artist": "One Direction",
        "album": "Up All Night",
        "genre": "Pop",
        "release_date": "2011-09-11"
    },
    "Happier": {
        "artist": "Marshmello , Bastille",
        "album": "Happier - Single",
        "genre": "Pop",
        "release_date": "2018-08-17"
    },
    "DJ Got Us Fallin' In Love (feat. Pitbull)": {
        "artist": "USHER , Pitbull",
        "album": "Versus",
        "genre": "Pop",
        "release_date": "2010-07-20"
    },
    "God's Plan": {
        "artist": "Drake",
        "album": "Scorpion",
        "genre": "Hip Hop",
        "release_date": "2018-01-19"
    },
    "Sorry": {
        "artist": "Justin Bieber",
        "album": "Purpose",
        "genre": "Pop",
        "release_date": "2015-10-23"
    },
    "This Is What You Came For": {
        "artist": "Calvin Harris , Rihanna",
        "album": "This Is What You Came For - Single",
        "genre": "Electronic",
        "release_date": "2016-04-29"
    },
    "Shut Up and Dance": {
        "artist": "WALK THE MOON",
        "album": "TALKING IS HARD",
        "genre": "Indie Pop",
        "release_date": "2014-09-10"
    },
    "The Nights": {
        "artist": "Avicii",
        "album": "The Days / Nights",
        "genre": "Electronic",
        "release_date": "2014-11-01"
    },
    "Safe And Sound": {
        "artist": "Capital Cities",
        "album": "In a Tidal Wave of Mystery",
        "genre": "Indie Pop",
        "release_date": "2011-06-07"
    },
    "Look What You Made Me Do": {
        "artist": "Taylor Swift",
        "album": "Reputation",
        "genre": "Pop",
        "release_date": "2017-08-24"
    },
    "Sunflower - Spider-Man: Into the Spider-Verse": {
        "artist": "Post Malone , Swae Lee",
        "album": "Spider-Man: Into the Spider-Verse Soundtrack",
        "genre": "Hip Hop",
        "release_date": "2018-10-18"
    },
    "Lucid Dreams": {
        "artist": "Juice WRLD",
        "album": "Goodbye & Good Riddance",
        "genre": "Hip Hop",
        "release_date": "2018-05-04"
    },
    "Before You Go": {
        "artist": "Lewis Capaldi",
        "album": "Divinely Uninspired to a Hellish Extent",
        "genre": "Pop",
        "release_date": "2019-11-19"
    },
    "Just Give Me a Reason (feat. Nate Ruess)": {
        "artist": "P!nk , Nate Ruess",
        "album": "The Truth About Love",
        "genre": "Pop",
        "release_date": "2012-09-18"
    },
    "Passionfruit": {
        "artist": "Drake",
        "album": "More Life",
        "genre": "R&B",
        "release_date": "2017-03-18"
    },
    "Maps": {
        "artist": "Maroon 5",
        "album": "V",
        "genre": "Pop",
        "release_date": "2014-06-16"
    },
    "Treat You Better": {
        "artist": "Shawn Mendes",
        "album": "Illuminate",
        "genre": "Pop",
        "release_date": "2016-06-03"
    },
    "Sugar, We're Goin Down": {
        "artist": "Fall Out Boy",
        "album": "From Under the Cork Tree",
        "genre": "Pop Punk",
        "release_date": "2005-04-12"
    },
    "Kiss Me Thru The Phone": {
        "artist": "Soulja Boy , Sammie",
        "album": "iSouljaBoyTellem",
        "genre": "Hip Hop",
        "release_date": "2008-11-27"
    },
    "Hung Up": {
        "artist": "Madonna",
        "album": "Confessions on a Dance Floor",
        "genre": "Pop",
        "release_date": "2005-10-17"
    },
    "Hot In Herre": {
        "artist": "Nelly",
        "album": "Nellyville",
        "genre": "Hip Hop",
        "release_date": "2002-04-16"
    },
    "So What": {
        "artist": "P!nk",
        "album": "Funhouse",
        "genre": "Pop Rock",
        "release_date": "2008-08-11"
    },
    "What's Luv? (feat. Ja-Rule & Ashanti)": {
        "artist": "Fat Joe , Ja Rule",
        "album": "Jealous Ones Still Envy (J.O.S.E.)",
        "genre": "Hip Hop",
        "release_date": "2002-02-26"
    },
    "Wherever You Will Go": {
        "artist": "The Calling",
        "album": "Camino Palmero",
        "genre": "Alternative Rock",
        "release_date": "2001-05-22"
    },
    "Dance, Dance": {
        "artist": "Fall Out Boy",
        "album": "From Under the Cork Tree",
        "genre": "Pop Punk",
        "release_date": "2005-06-28"
    },
    "Young Folks": {
        "artist": "Peter Bjorn and John",
        "album": "Writer's Block",
        "genre": "Indie Pop",
        "release_date": "2006-08-23"
    },
    "Just Dance": {
        "artist": "Lady Gaga , Colby O'Donis",
        "album": "The Fame",
        "genre": "Pop",
        "release_date": "2008-04-08"
    },
    "In Too Deep": {
        "artist": "Sum 41",
        "album": "All Killer No Filler",
        "genre": "Pop Punk",
        "release_date": "2001-11-26"
    },
    "Party In The U.S.A.": {
        "artist": "Miley Cyrus",
        "album": "The Time of Our Lives",
        "genre": "Pop",
        "release_date": "2009-08-11"
    },
    "Don't Know Why": {
        "artist": "Norah Jones",
        "album": "Come Away with Me",
        "genre": "Jazz",
        "release_date": "2002-02-26"
    },
    "Are You Gonna Be My Girl": {
        "artist": "Jet",
        "album": "Get Born",
        "genre": "Garage Rock",
        "release_date": "2003-09-29"
    },
    "You're Beautiful": {
        "artist": "James Blunt",
        "album": "Back to Bedlam",
        "genre": "Pop",
        "release_date": "2005-05-30"
    },
    "Bleeding Love": {
        "artist": "Leona Lewis",
        "album": "Spirit",
        "genre": "Pop",
        "release_date": "2007-10-19"
    },
    "This Is The Life": {
        "artist": "Amy Macdonald",
        "album": "This Is The Life",
        "genre": "Pop Rock",
        "release_date": "2007-07-30"
    },
    "Savior": {
        "artist": "Rise Against",
        "album": "Appeal to Reason",
        "genre": "Punk Rock",
        "release_date": "2008-06-03"
    },
    "Rude Boy": {
        "artist": "Rihanna",
        "album": "Rated R",
        "genre": "Dancehall",
        "release_date": "2010-02-19"
    },
    "Love in This Club (feat. Young Jeezy)": {
        "artist": "USHER , Jeezy",
        "album": "Here I Stand",
        "genre": "R&B",
        "release_date": "2008-03-18"
    },
    "Dog Days Are Over": {
        "artist": "Florence + The Machine",
        "album": "Lungs",
        "genre": "Indie Pop",
        "release_date": "2008-12-03"
    },
    "It Wasn't Me": {
        "artist": "Shaggy , Rik Rok",
        "album": "Hot Shot",
        "genre": "Reggae Fusion",
        "release_date": "2000-11-29"
    },
    "Sk8er Boi": {
        "artist": "Avril Lavigne",
        "album": "Let Go",
        "genre": "Pop Punk",
        "release_date": "2002-06-04"
    },
    "When You Were Young": {
        "artist": "The Killers",
        "album": "Sam's Town",
        "genre": "Alternative Rock",
        "release_date": "2006-09-18"
    },
    "Uprising": {
        "artist": "Muse",
        "album": "The Resistance",
        "genre": "Alternative Rock",
        "release_date": "2009-08-03"
    },
    "Here Without You": {
        "artist": "3 Doors Down",
        "album": "Away from the Sun",
        "genre": "Alternative Rock",
        "release_date": "2002-11-11"
    },
    "Alors on danse - Radio Edit": {
        "artist": "Stromae",
        "album": "Alors on danse - Single",
        "genre": "Electropop",
        "release_date": "2009-03-01"
    },
    "Ride Wit Me": {
        "artist": "Nelly , City Spud",
        "album": "Country Grammar",
        "genre": "Hip Hop",
        "release_date": "2001-06-25"
    },
    "Kids": {
        "artist": "MGMT",
        "album": "Oracular Spectacular",
        "genre": "Indie Pop",
        "release_date": "2008-10-13"
    },
    "Because Of You": {
        "artist": "Ne-Yo",
        "album": "Year of the Gentleman",
        "genre": "R&B",
        "release_date": "2007-04-25"
    },
    "Dancing in the Moonlight": {
        "artist": "Toploader",
        "album": "Onka's Big Moka",
        "genre": "Pop Rock",
        "release_date": "1999-11-01"
    },
    "Miss Independent": {
        "artist": "Ne-Yo",
        "album": "Year of the Gentleman",
        "genre": "R&B",
        "release_date": "2008-08-28"
    },
    "Use Somebody": {
        "artist": "Kings of Leon",
        "album": "Only by the Night",
        "genre": "Alternative Rock",
        "release_date": "2008-12-08"
    },
    "Womanizer": {
        "artist": "Britney Spears",
        "album": "Circus",
        "genre": "Pop",
        "release_date": "2008-10-03"
    },
    "Cooler Than Me - Single Mix": {
        "artist": "Mike Posner , Gigamesh",
        "album": "Cooler Than Me - Single",
        "genre": "Pop",
        "release_date": "2010-04-16"
    },
    "Forever": {
        "artist": "Chris Brown",
        "album": "Exclusive",
        "genre": "R&B",
        "release_date": "2008-04-29"
    },
    "Forgot About Dre": {
        "artist": "Dr. Dre , Eminem",
        "album": "2001",
        "genre": "Hip Hop",
        "release_date": "2000-11-21"
    },
    "One, Two Step (feat. Missy Elliott)": {
        "artist": "Ciara , Missy Elliott",
        "album": "Goodies",
        "genre": "R&B",
        "release_date": "2004-07-13"
    },
    "Circus": {
        "artist": "Britney Spears",
        "album": "Circus",
        "genre": "Pop",
        "release_date": "2008-12-02"
    },
    "Boulevard of Broken Dreams": {
        "artist": "Green Day",
        "album": "American Idiot",
        "genre": "Alternative Rock",
        "release_date": "2004-09-21"
    },
    "All The Things She Said": {
        "artist": "t.A.T.u.",
        "album": "200 km/h in the Wrong Lane",
        "genre": "Pop",
        "release_date": "2002-12-19"
    },
    "One Last Breath": {
        "artist": "Creed",
        "album": "Weathered",
        "genre": "Alternative Rock",
        "release_date": "2001-05-22"
    },
    "Welcome to the Black Parade": {
        "artist": "My Chemical Romance",
        "album": "The Black Parade",
        "genre": "Alternative Rock",
        "release_date": "2006-09-12"
    },
    "Fireflies": {
        "artist": "Owl City",
        "album": "Ocean Eyes",
        "genre": "Synthpop",
        "release_date": "2009-07-14"
    },
    "Right Now (Na Na Na)": {
        "artist": "Akon",
        "album": "Freedom",
        "genre": "R&B",
        "release_date": "2008-09-30"
    },
    "Somewhere Only We Know": {
        "artist": "Keane",
        "album": "Hopes and Fears",
        "genre": "Alternative Rock",
        "release_date": "2004-02-16"
    },
    "Teenage Dirtbag": {
        "artist": "Wheatus",
        "album": "Wheatus",
        "genre": "Pop Rock",
        "release_date": "2000-06-12"
    },
    "Whenever, Wherever": {
        "artist": "Shakira",
        "album": "Laundry Service",
        "genre": "Pop",
        "release_date": "2001-08-27"
    },
    "Wake Me up When September Ends": {
        "artist": "Green Day",
        "album": "American Idiot",
        "genre": "Alternative Rock",
        "release_date": "2005-06-13"
    },
    "Get Busy": {
        "artist": "Sean Paul",
        "album": "Dutty Rock",
        "genre": "Dancehall",
        "release_date": "2003-02-24"
    },
    "Learn to Fly": {
        "artist": "Foo Fighters",
        "album": "There Is Nothing Left to Lose",
        "genre": "Alternative Rock",
        "release_date": "1999"
    },
    "Better Off Alone": {
        "artist": "Alice Deejay",
        "album": "Who Needs Guitars Anyway?",
        "genre": "Eurodance",
        "release_date": "1998"
    },
    "There She Goes": {
        "artist": "The La's",
        "album": "The La's",
        "genre": "Indie Pop",
        "release_date": "1988"
    },
    "One": {
        "artist": "U2",
        "album": "Achtung Baby",
        "genre": "Rock",
        "release_date": "1991"
    },
    "Don't Cry (Original)": {
        "artist": "Guns N' Roses",
        "album": "Use Your Illusion I",
        "genre": "Hard Rock",
        "release_date": "1991"
    },
    "What Is Love - 7\" Mix": {
        "artist": "Haddaway",
        "album": "The Album",
        "genre": "Eurodance",
        "release_date": "1993"
    },
    "Wonderwall - Remastered": {
        "artist": "Oasis",
        "album": "(What's the Story) Morning Glory?",
        "genre": "Britpop",
        "release_date": "1995"
    },
    "Return of the Mack": {
        "artist": "Mark Morrison",
        "album": "Return of the Mack",
        "genre": "R&B",
        "release_date": "1996"
    },
    "Kiss from a Rose": {
        "artist": "Seal",
        "album": "Seal II",
        "genre": "Pop",
        "release_date": "1994"
    },
    "Give It Away": {
        "artist": "Red Hot Chili Peppers",
        "album": "Blood Sugar Sex Magik",
        "genre": "Funk Rock",
        "release_date": "1991"
    },
    "Fantasy": {
        "artist": "Mariah Carey",
        "album": "Daydream",
        "genre": "Pop, R&B",
        "release_date": "1995"
    },
    "The Man Who Sold The World - Live": {
        "artist": "Nirvana",
        "album": "MTV Unplugged in New York",
        "genre": "Grunge",
        "release_date": "1994"
    },
    "All That She Wants": {
        "artist": "Ace of Base",
        "album": "Happy Nation",
        "genre": "Eurodance, Reggae",
        "release_date": "1992"
    },
    "Enter Sandman (Remastered)": {
        "artist": "Metallica",
        "album": "Metallica",
        "genre": "Heavy Metal",
        "release_date": "1991"
    },
    "Jump Around - 30 Years Remaster": {
        "artist": "House Of Pain",
        "album": "House of Pain",
        "genre": "Hip Hop",
        "release_date": "1992"
    },
    "High and Dry": {
        "artist": "Radiohead",
        "album": "The Bends",
        "genre": "Alternative Rock",
        "release_date": "1995"
    },
    "Genie In a Bottle": {
        "artist": "Christina Aguilera",
        "album": "Christina Aguilera",
        "genre": "Pop",
        "release_date": "1999"
    },
    "1979 - Remastered 2012": {
        "artist": "The Smashing Pumpkins",
        "album": "Mellon Collie and the Infinite Sadness",
        "genre": "Alternative Rock",
        "release_date": "1995"
    },
    "I Will Always Love You": {
        "artist": "Whitney Houston",
        "album": "The Bodyguard: Original Soundtrack Album",
        "genre": "R&B, Soul",
        "release_date": "1992"
    },
    "Freed From Desire - prod. Molella, Phil Jay": {
        "artist": "Gala , Molella",
        "album": "Come into My Life",
        "genre": "Eurodance",
        "release_date": "1996"
    },
    "Maria Maria (feat. The Product G&B)": {
        "artist": "Santana , The Product G&B",
        "album": "Supernatural",
        "genre": "Latin Rock",
        "release_date": "1999"
    },
    "Alright": {
        "artist": "Supergrass",
        "album": "I Should Coco",
        "genre": "Britpop",
        "release_date": "1995"
    },
    "My Hero": {
        "artist": "Foo Fighters",
        "album": "The Colour and the Shape",
        "genre": "Alternative Rock",
        "release_date": "1998"
    },
    "Mambo No. 5 (a Little Bit of...)": {
        "artist": "Lou Bega",
        "album": "A Little Bit of Mambo",
        "genre": "Mambo",
        "release_date": "1999"
    },
    "Pretty Fly (For A White Guy)": {
        "artist": "The Offspring",
        "album": "Americana",
        "genre": "Punk Rock",
        "release_date": "1998"
    },
    "Mr. Jones": {
        "artist": "Counting Crows",
        "album": "August and Everything After",
        "genre": "Alternative Rock",
        "release_date": "1993"
    },
    "Believe": {
        "artist": "Cher",
        "album": "Believe",
        "genre": "Dance-Pop",
        "release_date": "1998"
    },
    "No Diggity": {
        "artist": "Blackstreet , Dr. Dre",
        "album": "Another Level",
        "genre": "R&B, Hip Hop",
        "release_date": "1996"
    },
    "It Ain't Over 'Til It's Over": {
        "artist": "Lenny Kravitz",
        "album": "Mama Said",
        "genre": "Rock, R&B",
        "release_date": "1991"
    },
    "Angels": {
        "artist": "Robbie Williams",
        "album": "Life thru a Lens",
        "genre": "Pop Rock",
        "release_date": "1997"
    },
    "Crazy": {
        "artist": "Aerosmith",
        "album": "Get a Grip",
        "genre": "Hard Rock",
        "release_date": "1993"
    },
    "No Rain": {
        "artist": "Blind Melon",
        "album": "Blind Melon",
        "genre": "Alternative Rock",
        "release_date": "1992"
    },
    "Alive": {
        "artist": "Pearl Jam",
        "album": "Ten",
        "genre": "Grunge",
        "release_date": "1991"
    },
    "Semi-Charmed Life": {
        "artist": "Third Eye Blind",
        "album": "Third Eye Blind",
        "genre": "Alternative Rock",
        "release_date": "1997"
    },
    "Buddy Holly": {
        "artist": "Weezer",
        "album": "Weezer (Blue Album)",
        "genre": "Alternative Rock",
        "release_date": "1994"
    },
    "When I Come Around": {
        "artist": "Green Day",
        "album": "Dookie",
        "genre": "Pop Punk",
        "release_date": "1994"
    },
    "It Must Have Been Love - From the Film \"Pretty Woman\"": {
        "artist": "Roxette",
        "album": "Pearls of Passion",
        "genre": "Pop Rock",
        "release_date": "1990"
    },
    "Barbie Girl": {
        "artist": "Aqua",
        "album": "Aquarium",
        "genre": "Eurodance",
        "release_date": "1997"
    },
    "You Get What You Give": {
        "artist": "New Radicals",
        "album": "Maybe You've Been Brainwashed Too",
        "genre": "Pop Rock",
        "release_date": "1998"
    },
    "Self Esteem": {
        "artist": "The Offspring",
        "album": "Smash",
        "genre": "Punk Rock",
        "release_date": "1994"
    },
    "Always": {
        "artist": "Bon Jovi",
        "album": "Cross Road",
        "genre": "Rock",
        "release_date": "1994"
    },
    "Livin' la Vida Loca": {
        "artist": "Ricky Martin",
        "album": "Ricky Martin",
        "genre": "Latin Pop",
        "release_date": "1999"
    },
    "Lemon Tree": {
        "artist": "Fools Garden",
        "album": "Dish of the Day",
        "genre": "Pop Rock",
        "release_date": "1995"
    },
    "Come As You Are": {
        "artist": "Nirvana",
        "album": "Nevermind",
        "genre": "Grunge",
        "release_date": "1991"
    },
    "Don't Speak": {
        "artist": "No Doubt",
        "album": "Tragic Kingdom",
        "genre": "Ska Punk",
        "release_date": "1996"
    },
    "Everybody Hurts": {
        "artist": "R.E.M.",
        "album": "Automatic for the People",
        "genre": "Alternative Rock",
        "release_date": "1992"
    },
    "Nuthin' But A \"G\" Thang": {
        "artist": "Dr. Dre , Snoop Dogg",
        "album": "The Chronic",
        "genre": "Gangsta Rap",
        "release_date": "1992"
    },
    "My Name Is": {
        "artist": "Eminem",
        "album": "The Slim Shady LP",
        "genre": "Hip Hop",
        "release_date": "1999"
    },
    "Just A Girl": {
        "artist": "No Doubt",
        "album": "Tragic Kingdom",
        "genre": "Ska Punk",
        "release_date": "1995"
    },
    "Thank You": {
        "artist": "Dido",
        "album": "No Angel",
        "genre": "Pop",
        "release_date": "1998"
    }
}


import random
import feedparser
import json
import pandas as pd
from src.pyRandomMedia.songs_file import songs

def get_song(genre, artist=None, song_name=None, release_date=None):
    if type(genre) != str or (artist is not None and type(artist) != str) or (song_name is not None and type(song_name) != str) or (release_date is not None and type(release_date) != str):
        raise TypeError("Please input strings only (including the release date!!)")
    possible_songs = {}
    for song in songs.keys():
        if genre in songs[song]["genre"]:
            if artist == None or artist in songs[song]["artist"]:
                if song_name == None or song_name in song:
                    if release_date == None or songs[song]["release_date"][:4] == release_date:
                        possible_songs[song] = songs[song]
    if possible_songs:
        return random.choice(list(possible_songs.items()))
    else:
        return "No songs found in our list"





""" 
inputObj is the object which holds function options;

Sample input:
{
"inTitle": "Dam", #String in title of article
"num": 15, #Max number of articles to return. 
}
"""

def get_news(inputObj = {}):

    # Fetch the RSS feed
    feed = feedparser.parse('https://news.google.com/rss?hl=en-US&gl=US&ceid=US:en');

    # Initialize an empty list to store parsed items
    parsed_items = []

    #keep count of items for num; 
    count = 0; 

    # Iterate over each item in the feed and parse relevant data
    for item in feed.entries:

        parsed_item = {
            'title': item.title,
            'link': item.link,
            'pubDate': item.published,
            'source': {
                'url': item.source.url,
                'name': item.source.title
            }
        }

        if("inTitle" in inputObj.keys()):
        
            if(inputObj["inTitle"] in parsed_item["title"]):
                parsed_items.append(parsed_item);
                count+=1;
        else:
            parsed_items.append(parsed_item);
            count+=1;

        if("num" in inputObj.keys() and count == inputObj["num"]):
            return parsed_items
        

    # Convert the parsed items list to JSON format
    return parsed_items


def get_random_TV_show():
    data = pd.read_csv('src/pyRandomMedia/netflix_titles.csv')
    data = data[(data['type'] == 'TV Show') & (data['director'].notnull()) & (data['cast'].notnull()) & (data['release_year'].notnull())]
    data = data.reset_index(drop=True)

    rand = random.randint(0, len(data) - 1)
    dic = data.iloc[rand][['title', 'director', 'cast', 'release_year']].to_dict()
    return dic



import setuptools

with open("README.md", "r", encoding = "utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name = "pyrandommedia",
    version = "0.0.4",
    author = "Stan, Nicholas, Benson, Sangely",
    description = "A package used to generate random media for website testing. This includes songs, movies, news and Tv shows.",
    long_description = long_description,
    long_description_content_type = "text/markdown",
    url = "https://github.com/software-students-spring2024/3-python-package-exercise-team-kiwi",
    project_urls = {
        "Github Repo": "https://github.com/software-students-spring2024/3-python-package-exercise-team-kiwi",
    },
    classifiers = [
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
    ],
    package_dir = {"": "src"},
    packages = setuptools.find_packages(where="src"),
    install_requires=[
        "feedparser",
        "pandas"
    ],
    python_requires = ">=3.6"
)